==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/NodeSelectorFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NodeSelectorFluent<A extends io.fabric8.kubernetes.api.model.NodeSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToNodeSelectorTerms(java.lang.Integer index,io.fabric8.kubernetes.api.model.NodeSelectorTerm item);
  public A setToNodeSelectorTerms(java.lang.Integer index,io.fabric8.kubernetes.api.model.NodeSelectorTerm item);
  public A addToNodeSelectorTerms(io.fabric8.kubernetes.api.model.NodeSelectorTerm... items);
  public A addAllToNodeSelectorTerms(java.util.Collection<io.fabric8.kubernetes.api.model.NodeSelectorTerm> items);
  public A removeFromNodeSelectorTerms(io.fabric8.kubernetes.api.model.NodeSelectorTerm... items);
  public A removeAllFromNodeSelectorTerms(java.util.Collection<io.fabric8.kubernetes.api.model.NodeSelectorTerm> items);
  public A removeMatchingFromNodeSelectorTerms(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNodeSelectorTerms instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.NodeSelectorTerm> getNodeSelectorTerms();
  public java.util.List<io.fabric8.kubernetes.api.model.NodeSelectorTerm> buildNodeSelectorTerms();
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildNodeSelectorTerm(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildFirstNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildLastNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildMatchingNodeSelectorTerm(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder> predicate);
  public java.lang.Boolean hasMatchingNodeSelectorTerm(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder> predicate);
  public A withNodeSelectorTerms(java.util.List<io.fabric8.kubernetes.api.model.NodeSelectorTerm> nodeSelectorTerms);
  public A withNodeSelectorTerms(io.fabric8.kubernetes.api.model.NodeSelectorTerm... nodeSelectorTerms);
  public java.lang.Boolean hasNodeSelectorTerms();
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> addNewNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> addNewNodeSelectorTermLike(io.fabric8.kubernetes.api.model.NodeSelectorTerm item);
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> setNewNodeSelectorTermLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.NodeSelectorTerm item);
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> editNodeSelectorTerm(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> editFirstNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> editLastNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> editMatchingNodeSelectorTerm(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder> predicate);
  public interface NodeSelectorTermsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NodeSelectorTermFluent<io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<N>>{
    public N and();
    public N endNodeSelectorTerm();
    
  }
  
}

==> kubernetes-model-core-5.12.1-sources.jar: io/fabric8/kubernetes/api/model/NodeSelectorFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NodeSelectorFluent<A extends io.fabric8.kubernetes.api.model.NodeSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToNodeSelectorTerms(java.lang.Integer index,io.fabric8.kubernetes.api.model.NodeSelectorTerm item);
  public A setToNodeSelectorTerms(java.lang.Integer index,io.fabric8.kubernetes.api.model.NodeSelectorTerm item);
  public A addToNodeSelectorTerms(io.fabric8.kubernetes.api.model.NodeSelectorTerm... items);
  public A addAllToNodeSelectorTerms(java.util.Collection<io.fabric8.kubernetes.api.model.NodeSelectorTerm> items);
  public A removeFromNodeSelectorTerms(io.fabric8.kubernetes.api.model.NodeSelectorTerm... items);
  public A removeAllFromNodeSelectorTerms(java.util.Collection<io.fabric8.kubernetes.api.model.NodeSelectorTerm> items);
  public A removeMatchingFromNodeSelectorTerms(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNodeSelectorTerms instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.NodeSelectorTerm> getNodeSelectorTerms();
  public java.util.List<io.fabric8.kubernetes.api.model.NodeSelectorTerm> buildNodeSelectorTerms();
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildNodeSelectorTerm(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildFirstNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildLastNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorTerm buildMatchingNodeSelectorTerm(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder> predicate);
  public java.lang.Boolean hasMatchingNodeSelectorTerm(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder> predicate);
  public A withNodeSelectorTerms(java.util.List<io.fabric8.kubernetes.api.model.NodeSelectorTerm> nodeSelectorTerms);
  public A withNodeSelectorTerms(io.fabric8.kubernetes.api.model.NodeSelectorTerm... nodeSelectorTerms);
  public java.lang.Boolean hasNodeSelectorTerms();
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> addNewNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> addNewNodeSelectorTermLike(io.fabric8.kubernetes.api.model.NodeSelectorTerm item);
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> setNewNodeSelectorTermLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.NodeSelectorTerm item);
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> editNodeSelectorTerm(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> editFirstNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> editLastNodeSelectorTerm();
  public io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<A> editMatchingNodeSelectorTerm(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NodeSelectorTermBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface NodeSelectorTermsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NodeSelectorTermFluent<io.fabric8.kubernetes.api.model.NodeSelectorFluent.NodeSelectorTermsNested<N>>{
    public N and();
    public N endNodeSelectorTerm();
    
  }
  
}
